<?php
/* #######
 * ##  wassupOptions - A PHP Class for Wassup plugin option settings.
 * ##    Contains variables and functions used to set or change wassup 
 * ##    settings in Wordpress' wp_options table and to output those
 * ##    values for use in forms.
 * ##  Author: Helene D. 2/24/08
 */
class wassupOptions {
	/* general/detail settings */
	var $wassup_refresh = "3";
	var $wassup_userlevel = "8";
	var $wassup_screen_res = "800";
	var $wassup_default_type = "";
	var $wassup_default_limit = "10";

	/* recording settings */
	var $wassup_active = "1";
	var $wassup_loggedin = "1";
	var $wassup_spider = "1";
	var $wassup_attack = "1";
	var $wassup_exclude;
	var $wassup_exclude_url;

	/* spam settings */
	var $wassup_spamcheck;
        var $wassup_spam;
        var $wassup_refspam;

	/* table/file management settings */
	var $wassup_savepath;
	var $delete_auto;
        var $delete_auto_size;
	var $wassup_remind_mb;
	var $wassup_remind_flag;
	var $wassup_uninstall;	//new - for complete uninstall of wassup

	/* chart display settings */
	var $wassup_chart;
	var $wassup_chart_type;

	/* widget settings */
	var $wassup_widget_title;
	var $wassup_widget_ulclass;
	var $wassup_widget_loggedin;
	var $wassup_widget_comauth;
	var $wassup_widget_search;
	var $wassup_widget_searchlimit;
	var $wassup_widget_ref;
	var $wassup_widget_reflimit;
	var $wassup_widget_topbr;
	var $wassup_widget_topbrlimit;
	var $wassup_widget_topos;
	var $wassup_widget_toposlimit;
	var $wassup_widget_chars;

	/* temporary action settings */
	var $wassup_alert_message;	//new - used to display alerts
	var $wmark;
	var $wip;

	/* Constructor */
	function wassupoptions() {
		//# initialize class variables with current options 
		//# or with defaults if none
		$this->loadSettings();
	}

	/* Methods */
	function loadDefaults() {
		$this->wassup_active = "1";
		$this->wassup_loggedin = "1";
		$this->wassup_spider = "1";
		$this->wassup_attack = "1";
		$this->wassup_spamcheck = "1";
        	$this->wassup_spam = "1";
        	$this->wassup_refspam = "1";
		$this->wassup_exclude = "";
		$this->wassup_exclude_url = "";
		$this->wassup_savepath = null;
		$this->wassup_chart = "1";
		$this->wassup_chart_type = "2";
		$this->delete_auto = "never";
        	$this->delete_auto_size = "0";
		$this->wassup_remind_mb = "0";
		$this->wassup_remind_flag = "0";
		$this->wassup_refresh = "3";
		$this->wassup_userlevel = "8";
		$this->wassup_screen_res = "800";
		$this->wassup_default_type = "everything";
		$this->wassup_default_limit = "10";
		$this->wassup_widget_title = "Visitors Online";
		$this->wassup_widget_ulclass = "links";
		$this->wassup_widget_loggedin = "1";
		$this->wassup_widget_comauth = "1";
		$this->wassup_widget_search = "1";
		$this->wassup_widget_searchlimit = "5";
		$this->wassup_widget_ref = "1";
		$this->wassup_widget_reflimit = "5";
		$this->wassup_widget_topbr = "1";
		$this->wassup_widget_topbrlimit = "5";
		$this->wassup_widget_topos = "1";
		$this->wassup_widget_toposlimit = "5";
		$this->wassup_widget_chars = "18";
		$this->wassup_alert_message = "";
		$this->wassup_uninstall = "0";
	}

	//#Load class variables with current options or with defaults 
	function loadSettings() {
		//# load class variables with current options or load
		//#   default settings if no options set.
		$options_array = get_option('wassup_settings');
		if (empty($options_array)) {
			$this->loadDefaults();
		} else {
			foreach ($options_array as $optionkey => $optionvalue) {
				//if (isset($this->$optionkey)) { //returns false for null values
				if (array_key_exists($optionkey,$this)) {
					$this->$optionkey = $optionvalue;
				}
			}
		}
		return true;
	}

	//#Save class variables to the Wordpress options table
	function saveSettings() {
		//#  convert class variables into an array and save using
		//#  Wordpress functions, "update_option" or "add_option"
		//#convert class into array...
		$settings_array = array();
		foreach (array_keys(get_class_vars(get_class($this))) as $k) {
			$settings_array[$k] = $this->$k;
		}
		//#save array to options table...
		$options_check = get_option('wassup_settings');
		if (empty($options_check)) {
			add_option('wassup_settings', $settings_array, 'Options for WassUp');
		} else {
			update_option('wassup_settings', $settings_array);
		}
		return true;
	}

	function deleteSettings() {
		//#delete the contents of the options table...
		delete_option('wassup_settings');
	}

	//#Return an array containing all possible values of the given 
	//#  class variable, $key. For use in form validation, etc.
	function getItemOptions($key="",$meta="") {
		$item_options = array();
		$item_options_meta = array();
		if ($key == "wassup_screen_res") {
			$item_options = array("640","800","1024","1200");
			$item_options_meta = array("&nbsp;640",
				"&nbsp;800",
				"1024",
				"1200");
		} elseif ($key == "wassup_userlevel") {
			$item_options = array("","8","6","2");
			$item_options_meta = array("--",
				__("Administrators","wassup"),
				__("Contributors","wassup"),
				__("Authors","wassup"));
		} elseif ($key == "wassup_chart_type") {
			$item_options = array("1","2");
			$item_options_meta = array(
				__("One - two lines chart one axis","wassup"),
				__("Two - two lines chart two axes","wassup"));
		} elseif ($key == "wassup_default_type") {
			$item_options = array("everything","spiders","nospider","spam","nospam","nospamspider","comauthor","searchengine","referrer");
			$item_options_meta = array(
				__("Everything","wassup"),
				__("Spiders","wassup"),
				__("No spider","wassup"),
				__("Spam","wassup"),
				__("No Spam","wassup"),
				__("No Spam, No Spider","wassup"),
				__("Comment authors","wassup"),
				__("Referer from search engine","wassup"),
				__("Referer from ext link","wassup"));
		} elseif ($key == "wassup_default_limit") {
			$item_options = array("10","20","50","100");
			$item_options_meta = array("&nbsp;10",
				"&nbsp;20",
				"&nbsp;50",
				"100");
		} elseif ($key == "delete_auto") {
			$item_options = array("never","-1 day","-1 week","-1 month","-3 months","-6 months","-1 year");
			$item_options_meta = array(
				__("Don't delete anything","wassup"),
				__("24 hours","wassup"),
				__("1 week","wassup"),
				__("1 month","wassup"),
				__("3 months","wassup"),
				__("6 months","wassup"),
				__("1 year","wassup"));
		} elseif (!empty($key)) {	//enable/disable is default
			$item_options =  array("1","0");
			$item_options_meta =  array("Enable","Disable");
		}
		if ($meta == "meta") {
			return $item_options_meta;
		} else {
			return $item_options;
		}
	} //end getItemValues

	//#generates <options> tags for the given class variable, $itemkey 
	//#  for use in a <select> form.
	function showFormOptions ($itemkey="") {
		$form_items =$this->getItemOptions($itemkey);
		$form_items_meta = $this->getItemOptions($itemkey,"meta");
		if (count($form_items) > 1) {
			$i = 0;
			foreach ($form_items as $k => $option_item) {
	        		echo "\n\t\t".'<option value="'.$option_item.'"';
	        		if ($this->$itemkey == $option_item) { echo ' SELECTED>'; }
				else { echo '>'; }
				echo $form_items_meta[$k].'&nbsp;&nbsp;</option>';
			}
		}
	} //end showFormOptions

	//#Return current PHP session.save_path value (pathname portion)
	function getSessionpath() {
		$sessionpath = session_save_path();
		if (strpos($sessionpath, ";") !== FALSE) {
  	   		$sessionpath = substr($sessionpath, strpos($sessionpath, ";")+1);
		}
		return rtrim($sessionpath,"/");
	}

	//#Return the value of class variable, wassup_savepath, if not null
	//#  or return PHP session.save_path (pathname portion)
	function getSavepath() {
		if (empty($this->wassup_savepath)) {
			return $this->getSessionpath();
		} else {
			return $this->wassup_savepath;
		}
	}

	//#Sets the class variable, wassup_savepath, with the given 
	//#  value $savepath
	function setSavepath($savepath="") {
		$savepath = rtrim($savepath,"/");
		if (empty($savepath) || $savepath == $this->getSessionpath()) {
			$this->wassup_savepath = NULL;
		} else {
			$this->wassup_savepath = $savepath;
		}
	}

	//#Return true if the given directory path exists and is writable
	function isWritableFolder($folderpath="") {
		$folderpath=trim($folderpath);	//remove white spaces
		if (!empty($folderpath) && file_exists($folderpath)) { 
			$testfile = rtrim($folderpath,"/")."/temp".time().'.txt';
			//#check that the directory is writable...
			if (@touch($testfile)) { unlink($testfile); }
			else { return false; }
		} else {
			return false;
		}
		return true;
	}

	//#show a system message in Wassup Admin menus
	function showMessage($message="") {
		if (empty($message) && !empty($this->wassup_alert_message)) {
			$message = $this->wassup_alert_message;
		}
		//#check for error message/notice message
		if (stristr($message,"error") !== FALSE || stristr($message,"problem") !== FALSE) {
			echo '<div class="fade error" id="wassup-error"><p style="color:#d00;padding-left:5px;">'.$message;
			//print_r($this); // #debug
			echo '</p></div>'."\n";
		} else {
			echo '<div class="fade updated" id="wassup-message"><p style="color:#040;padding-left:5px;">'.$message;
			//print_r($this); // #debug
			echo '</p></div>'."\n";
		}
	} //end showMessage

	function showError($message="") {
		$this->showMessage($message);
	}
} //end class wassupOptions

?>
